@@ -1,11 +1,11 @@
-# Copyright 2021 Q-CTRL. All rights reserved.
+# Copyright 2022 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
 # Proprietary and confidential. You may not use this file except in compliance
 # with the License. You may obtain a copy of the License at
 #
-#     https://q-ctrl.com/terms
+#    https://q-ctrl.com/terms
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
@@ -81,9 +81,7 @@ def main():
     ),
 )
 def generate_auth_file(
-    token: TokenType,
-    oidc_url: str = DEFAULT_OIDC_URL,
-    path: Path = None,
+    token: TokenType, oidc_url: str = DEFAULT_OIDC_URL, path: Path = None
 ) -> Any:
     """Generates the Q-CTRL Authentication file from command line.
 
@@ -286,6 +284,12 @@ def access_token(oidc_url, output):
     default=DEFAULT_API_ROOT,
     show_default=f"{DEFAULT_API_ROOT}",
 )
+@click.option(
+    "--oidc-url",
+    default=DEFAULT_OIDC_URL,
+    help="Custom Q-CTRL OIDC base URL.",
+    show_default=f"{DEFAULT_OIDC_URL}",
+)
 @click.option("--start-date", help="The date begin i.e 2020-12-31", required=True)
 @click.option("--end-date", help="The date till i.e 2021-06-30", required=True)
 @click.option(
@@ -301,7 +305,9 @@ def access_token(oidc_url, output):
     show_default="result.csv",
 )
 @click.option("--path", help="Path of saved file", required=True)
-def action_export(api_root, start_date, end_date, ignore_test_users, file_name, path):
+def action_export(
+    api_root, oidc_url, start_date, end_date, ignore_test_users, file_name, path
+):
     """
     Exports action data to csv file.
     """
@@ -309,7 +315,7 @@ def action_export(api_root, start_date, end_date, ignore_test_users, file_name,
     if not directory_path.exists():
         click.echo(f"Cannot find Path {directory_path}")
     else:
-        gql_api = create_gql_client(api_root, create_client_auth(api_root))
+        gql_api = create_gql_client(api_root, create_client_auth(oidc_url))
         action_export_query = ActionExportQuery(gql_api)
         result = action_export_query(start_date, end_date, ignore_test_users)
 
